@@ -19,9 +19,9 @@
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -69,16 +69,16 @@ namespace ost {
 
 using namespace std;
 
-NetworkDeviceInfo::NetworkDeviceInfo(const String& name, 
+NetworkDeviceInfo::NetworkDeviceInfo(const String& name,
 				     const IPV4Host& addr,
-				     const IPV4Broadcast& broadcast, 
+				     const IPV4Broadcast& broadcast,
 				     const IPV4Mask& netmask, int mtu)
-	: _name(name), _addr(addr), _broadcast(broadcast), _netmask(netmask), 
+	: _name(name), _addr(addr), _broadcast(broadcast), _netmask(netmask),
 	  _mtu(mtu)
 {}
 
 NetworkDeviceInfo::NetworkDeviceInfo(const NetworkDeviceInfo& ndi)
-	: _name(ndi._name), _addr(ndi._addr), _broadcast(ndi._broadcast), 
+	: _name(ndi._name), _addr(ndi._addr), _broadcast(ndi._broadcast),
 	  _netmask(ndi._netmask), _mtu(ndi._mtu)
 {}
 
@@ -88,7 +88,7 @@ NetworkDeviceInfo::~NetworkDeviceInfo()
 bool enumNetworkDevices(vector<NetworkDeviceInfo>& devs)
 {
 	devs.clear();
-	
+
 #ifndef WIN32
 	char buffer[8192];
 	struct ifconf ifc;
@@ -109,8 +109,7 @@ bool enumNetworkDevices(vector<NetworkDeviceInfo>& devs)
 	int mtu;
 
 	int count = ifc.ifc_len / sizeof(ifreq);
-	for(int i = 0; i < count; ++i)
-	{
+	for(int i = 0; i < count; ++i) {
 		if(ifc.ifc_req[i].ifr_addr.sa_family != AF_INET)
 			continue;
 
@@ -149,13 +148,11 @@ bool enumNetworkDevices(vector<NetworkDeviceInfo>& devs)
 	}
 
 	close(fd);
-#else // WIN32
+#elif defined(SIO_GET_INTERFACE_LIST) // WIN32
 
 	SOCKET s = WSASocket(AF_INET, SOCK_DGRAM, 0, 0, 0, 0);
-	if(s == INVALID_SOCKET)
-	{
-		if(WSAGetLastError() == WSANOTINITIALISED)
-		{
+	if(s == INVALID_SOCKET) {
+		if(WSAGetLastError() == WSANOTINITIALISED) {
 			WSADATA wsadata;
 			WSAStartup(MAKEWORD(2,0),&wsadata);
 		}
@@ -176,8 +173,7 @@ bool enumNetworkDevices(vector<NetworkDeviceInfo>& devs)
 	IPV4Broadcast brdaddr;
 	IPV4Mask maskaddr("0.0.0.0");
 
-	for(int i = 0; i < ifcount; ++i)
-	{
+	for(int i = 0; i < ifcount; ++i) {
 		addr = ((sockaddr_in&)iflist[i].iiAddress).sin_addr;
 		(IPV4Address&)brdaddr = ((sockaddr_in&)iflist[i].iiBroadcastAddress).sin_addr;
 		(IPV4Address&)maskaddr = ((sockaddr_in&)iflist[i].iiNetmask).sin_addr;
