@@ -19,9 +19,9 @@
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -60,24 +60,21 @@ using namespace std;
 #endif
 
 SimpleTCPStream::SimpleTCPStream(TCPSocket &server, size_t size)
-	: Socket(accept(server.getSocket(), NULL, NULL))
-{
+	: Socket(accept(server.getSocket(), NULL, NULL)) {
 	tpport_t port;
 	IPV4Host host = getPeer(&port);
 
-	if (! server.onAccept(host, port)) 
-	{
+	if (! server.onAccept(host, port)) {
 		endSocket();
 		error(errConnectRejected);
 		return;
 	}
-	
+
 	Socket::state = CONNECTED;
 }
-	
+
 SimpleTCPStream::SimpleTCPStream(const IPV4Host &host, tpport_t port, size_t size)
-	: Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
-{
+	: Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP) {
 	Connect(host, port, size);
 }
 
@@ -94,9 +91,8 @@ IPV4Host SimpleTCPStream::getSender(tpport_t *port) const
 void SimpleTCPStream::Connect(const IPV4Host &host, tpport_t port, size_t size)
 {
 	size_t i;
-	
-	for (i = 0 ; i < host.getAddressCount(); i++)
-	{
+
+	for (i = 0 ; i < host.getAddressCount(); i++) {
 		struct sockaddr_in addr;
 		memset(&addr, 0, sizeof(addr));
 		addr.sin_family = AF_INET;
@@ -110,8 +106,7 @@ void SimpleTCPStream::Connect(const IPV4Host &host, tpport_t port, size_t size)
 			break;
 	}
 
-	if (i == host.getAddressCount())
-	{
+	if (i == host.getAddressCount()) {
 		connectError();
 		endSocket();
 		return;
@@ -121,8 +116,7 @@ void SimpleTCPStream::Connect(const IPV4Host &host, tpport_t port, size_t size)
 }
 
 SimpleTCPStream::SimpleTCPStream()
-	: Socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)
-{
+	: Socket(PF_INET, SOCK_STREAM, IPPROTO_TCP) {
 	// Do nothing extra.
 }
 
@@ -133,12 +127,12 @@ SimpleTCPStream::SimpleTCPStream(const SimpleTCPStream &source) :
 	Socket(dup(source.so))
 #endif
 {
-}
+	}
 
-void SimpleTCPStream::endStream(void) 
+void SimpleTCPStream::endStream(void)
 {
 	endSocket();
-}
+	}
 
 ssize_t SimpleTCPStream::read(char *bytes, size_t length, timeout_t timeout)
 {
@@ -146,7 +140,7 @@ ssize_t SimpleTCPStream::read(char *bytes, size_t length, timeout_t timeout)
 	ssize_t rlen = 0;
 	size_t totalrecv = 0;
 	char *currentpos = bytes;
-	
+
 	// Check for reasonable requested length.
 	if (length < 1) {
 		return (ssize_t)totalrecv;
@@ -155,13 +149,12 @@ ssize_t SimpleTCPStream::read(char *bytes, size_t length, timeout_t timeout)
 	while (totalrecv < length) {
 		// Check for timeout condition.
 		if (timeout) {
-			if (! isPending(pendingInput, timeout))
-			{
+			if (! isPending(pendingInput, timeout)) {
 				error(errTimeout);
 				return -1;
 			}
 		}
-		
+
 		// Attempt to read data.
 		rlen = _IORET64 ::recv(so, (char *) currentpos, _IOLEN64 (length-totalrecv), 0);
 		if (rlen == 0 || rlen == -1) {
@@ -172,15 +165,15 @@ ssize_t SimpleTCPStream::read(char *bytes, size_t length, timeout_t timeout)
 		totalrecv += rlen;
 		currentpos += rlen;
 	}
-	
+
 	// Set error condition if necessary.
 	if (rlen == -1) {
 		error(errInput);
 	}
-	
+
 	// Return total number of bytes recieved.
 	return (ssize_t)totalrecv;
-}
+	}
 
 ssize_t SimpleTCPStream::write(const char *bytes, size_t length, timeout_t timeout)
 {
@@ -194,8 +187,7 @@ ssize_t SimpleTCPStream::write(const char *bytes, size_t length, timeout_t timeo
 
 	// Check for timeout condition.
 	if (timeout) {
-		if (! isPending(pendingOutput, timeout))
-		{
+		if (! isPending(pendingOutput, timeout)) {
 			error(errTimeout);
 			return -1;
 		}
@@ -207,8 +199,8 @@ ssize_t SimpleTCPStream::write(const char *bytes, size_t length, timeout_t timeo
 		error(errOutput);
 	}
 
-    return rlen;
-}
+	return rlen;
+	}
 
 ssize_t SimpleTCPStream::peek(char *bytes, size_t length, timeout_t timeout)
 {
@@ -225,8 +217,7 @@ ssize_t SimpleTCPStream::peek(char *bytes, size_t length, timeout_t timeout)
 	while (totalrecv < length) {
 		// Check for timeout condition.
 		if (timeout) {
-			if (! isPending(pendingInput, timeout))
-			{
+			if (! isPending(pendingInput, timeout)) {
 				error(errTimeout);
 				return -1;
 			}
@@ -237,8 +228,8 @@ ssize_t SimpleTCPStream::peek(char *bytes, size_t length, timeout_t timeout)
 		if (rlen == 0 || rlen == -1) {
 			break;
 		}
-        // cout << "received " << rlen << " bytes, remaining " << length - totalrecv << flush;
-		
+		// cout << "received " << rlen << " bytes, remaining " << length - totalrecv << flush;
+
 		totalrecv += rlen;
 		currentpos += rlen;
 	}
@@ -247,15 +238,15 @@ ssize_t SimpleTCPStream::peek(char *bytes, size_t length, timeout_t timeout)
 	if (rlen == -1) {
 		error(errInput);
 	}
-	
+
 	// Return total number of bytes recieved.
 	return (ssize_t)totalrecv;
-}
+	}
 
 bool SimpleTCPStream::isPending(Pending pending, timeout_t timeout)
 {
 	return Socket::isPending(pending, timeout);
-}
+	}
 
 #ifdef CCXX_NAMESPACES
 } /* for ost */
